@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006, 2007, 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,7 +36,6 @@
 #include "show_info.h"
 
 
-// Fixme, smb.conf path not completed etc.
 int conf_ok(gchar *file_path)
 {
     FILE *fp;
@@ -283,8 +282,9 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "guest ok = no\n");
     strcat(buffer, "public = no\n");
     strcat(buffer, "printable = no\n");
-    strcat(buffer, "share modes = no\n");
+// Deprecated    strcat(buffer, "share modes = no\n");
     strcat(buffer, "locking = no\n");
+    strcat(buffer, "strict locking = no\n");
 
     strcat(buffer, "\n");
     strcat(buffer, "[netlogon]\n");
@@ -297,8 +297,9 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "guest ok = no\n");
     strcat(buffer, "public = no\n");
     strcat(buffer, "printable = no\n");
-    strcat(buffer, "share modes = no\n");
+// Deprecated    strcat(buffer, "share modes = no\n");
     strcat(buffer, "locking = no\n");
+    strcat(buffer, "strict locking = no\n");
 
 
     /* Profiles are created automatically for each user, clients adds the files */
@@ -317,9 +318,10 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "guest ok = no\n");
     strcat(buffer, "public = no\n");
     strcat(buffer, "printable = no\n");
-    strcat(buffer, "locking = no\n");
     strcat(buffer, "create mode = 0600\n");
     strcat(buffer, "directory mask = 0700\n");
+    strcat(buffer, "locking = no\n");
+    strcat(buffer, "strict locking = no\n");
     
 
     strcat(buffer, "\n");
@@ -333,8 +335,10 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "guest ok = no\n");
     strcat(buffer, "public = no\n");
     strcat(buffer, "printable = yes\n");
-    strcat(buffer, "share modes = no\n");
+//Deprecated    strcat(buffer, "share modes = no\n");
     strcat(buffer, "locking = no\n");
+    strcat(buffer, "strict locking = no\n");
+
 
     /* We want to be able to print anything as pdf documents to a directory */
     strcat(buffer, "\n");
@@ -345,6 +349,8 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "browseable = yes\n");
     strcat(buffer, "writeable = yes\n");
     strcat(buffer, "guest ok = yes\n");
+    strcat(buffer, "locking = no\n");
+    strcat(buffer, "strict locking = no\n");
 
     /* The pdf printer service (converter) */
     strcat(buffer, "\n");
